Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(447)

Unified Diff: chrome/browser/resources/file_manager/js/metadata/metadata_cache.js

Issue 14658005: filemanager: Retrieve 'shared-with-me' property using getDriveEntryProperties API. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: update comments Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/file_manager/js/metadata/metadata_cache.js
diff --git a/chrome/browser/resources/file_manager/js/metadata/metadata_cache.js b/chrome/browser/resources/file_manager/js/metadata/metadata_cache.js
index 525e2d65c9adea35e69aa30596f329f6397c81e0..976fe99a7c4da6051352ee67eefd0c7ed627e670 100644
--- a/chrome/browser/resources/file_manager/js/metadata/metadata_cache.js
+++ b/chrome/browser/resources/file_manager/js/metadata/metadata_cache.js
@@ -799,9 +799,10 @@ DriveProvider.prototype.callApi_ = function() {
var self = this;
var task = function(url, callback) {
- chrome.fileBrowserPrivate.getDriveFileProperties(url, function(properties) {
- callback(self.convert_(properties, url));
- });
+ chrome.fileBrowserPrivate.getDriveEntryProperties(url,
+ function(properties) {
+ callback(self.convert_(properties, url));
+ });
};
for (var i = 0; i < urls.length; i++)
@@ -809,7 +810,7 @@ DriveProvider.prototype.callApi_ = function() {
};
/**
* @param {DriveFileProperties} data Drive file properties.
* @param {string} url File url.
* @return {boolean} True if the file is available offline.
*/
@@ -825,7 +826,7 @@ DriveProvider.isAvailableOffline = function(data, url) {
};
/**
* @param {DriveFileProperties} data Drive file properties.
* @return {boolean} True if opening the file does not require downloading it
* via a metered connection.
*/
@@ -852,7 +853,8 @@ DriveProvider.prototype.convert_ = function(data, url) {
contentUrl: (data.contentUrl || '').replace(/\?.*$/gi, ''),
editUrl: data.editUrl || '',
driveApps: data.driveApps || [],
- contentMimeType: data.contentMimeType || ''
+ contentMimeType: data.contentMimeType || '',
+ sharedWithMe: data.sharedWithMe
};
if (!data.isPresent) {
@@ -809,7 +810,7 @@ DriveProvider.prototype.callApi_ = function() {
};
/**
- * @param {DriveFileProperties} data Drive file properties.
+ * @param {DriveEntryProperties} data Drive entry properties.
* @param {string} url File url.
* @return {boolean} True if the file is available offline.
@@ -825,7 +826,7 @@ DriveProvider.isAvailableOffline = function(data, url) {
};
/**
- * @param {DriveFileProperties} data Drive file properties.
+ * @param {DriveEntryProperties} data Drive entry properties.
* @return {boolean} True if opening the file does not require downloading it
* via a metered connection.

Powered by Google App Engine
This is Rietveld 408576698